==> teamapps-client-0.9.11.zip: tsd/modules/formfield/UiSlider.d.ts <==
import { UiField } from "./UiField";
import { UiSliderConfig, UiSliderCommandHandler, UiSliderEventSource } from "../../generated/UiSliderConfig";
import { TeamAppsUiContext } from "../TeamAppsUiContext";
import { UiFieldEditingMode } from "../../generated/UiFieldEditingMode";
import { UiColorConfig } from "../../generated/UiColorConfig";
export declare class UiSlider extends UiField<UiSliderConfig, number> implements UiSliderEventSource, UiSliderCommandHandler {
    private uuid;
    private $main;
    private $style;
    private $slider;
    private slider;
    private min;
    private max;
    private step;
    private displayedDecimals;
    private tooltipPrefix;
    private tooltipPostfix;
    private humanReadableFileSize;
    protected initialize(config: UiSliderConfig, context: TeamAppsUiContext): void;
    isValidData(v: number): boolean;
    private createNoUiSliderOptions;
    protected displayCommittedValue(): void;
    getDefaultValue(): number;
    getFocusableElement(): JQuery;
    getMainInnerDomElement(): JQuery;
    getTransientValue(): number;
    protected onEditingModeChanged(editingMode: UiFieldEditingMode): void;
    valuesChanged(v1: number, v2: number): boolean;
    setSelectionColor(selectionColor: UiColorConfig): void;
    setDisplayedDecimals(displayedDecimals: number): void;
    setMax(max: number): void;
    setMin(min: number): void;
    setStep(step: number): void;
    setTooltipPostfix(tooltipPostfix: string): void;
    setTooltipPrefix(tooltipPrefix: string): void;
    setHumanReadableFileSize(humanReadableFileSize: boolean): void;
}

==> teamapps-client-0.9.23.zip: tsd/modules/formfield/UiSlider.d.ts <==
import { UiField } from "./UiField";
import { UiSliderConfig, UiSliderCommandHandler, UiSliderEventSource } from "../../generated/UiSliderConfig";
import { TeamAppsUiContext } from "../TeamAppsUiContext";
import { UiFieldEditingMode } from "../../generated/UiFieldEditingMode";
import { UiColorConfig } from "../../generated/UiColorConfig";
export declare class UiSlider extends UiField<UiSliderConfig, number> implements UiSliderEventSource, UiSliderCommandHandler {
    private uuid;
    private $main;
    private $style;
    private $slider;
    private slider;
    private min;
    private max;
    private step;
    private displayedDecimals;
    private tooltipPrefix;
    private tooltipPostfix;
    private humanReadableFileSize;
    protected initialize(config: UiSliderConfig, context: TeamAppsUiContext): void;
    isValidData(v: number): boolean;
    private createNoUiSliderOptions;
    protected displayCommittedValue(): void;
    getDefaultValue(): number;
    getFocusableElement(): HTMLElement;
    getMainInnerDomElement(): HTMLElement;
    getTransientValue(): number;
    protected onEditingModeChanged(editingMode: UiFieldEditingMode): void;
    valuesChanged(v1: number, v2: number): boolean;
    setSelectionColor(selectionColor: UiColorConfig): void;
    setDisplayedDecimals(displayedDecimals: number): void;
    setMax(max: number): void;
    setMin(min: number): void;
    setStep(step: number): void;
    setTooltipPostfix(tooltipPostfix: string): void;
    setTooltipPrefix(tooltipPrefix: string): void;
    setHumanReadableFileSize(humanReadableFileSize: boolean): void;
}
